function [Database] = Reading_Database(DataBase_file, Linea_Inicial, Linea_Final)

%% ---------------------------------------------------------------------------------
% Version:      26/08/2015                            
% (c):          Vicente Calabuig Simón
%               vicasim@etsid.upv.es
%
% 1.- Utilidad:
%
%       Dada una base de datos, en formato .txt o .dat, extraer
%       información parcial (o total) de la misma y almacenarla en memoria para su posterior manejo.
%
% 2.- Parámetros de entrada:
%
%       DataBase_file:   Archivo .txt o .dat que contiene a la base de datos                (.txt / .dat)
%       Linea_Inicial:   Linea de la base de datos en la que queremos comenzar la extración (num)
%       Linea_Final  :   Linea de la base de datos en la que queremos concluir la extración (num)
%
% 3.- Parámetros de salida:
%    
%       Database     :   Cell Array con la información extraída de la base de datos         (Cell)
%
% 4.- Ejemplo de uso:
%
%   [Database] = Reading_Database('earth_nav.dat', 1, 26590)
%   [Database] = Reading_Database('3_12_13_Database_Lat_Sorted.dat', 1, 9449)
%% ---------------------------------------------------------------------------------------------------------
fileID   = fopen(DataBase_file);

if fileID == -1
    fprintf('ERROR: Sin acceso al fichero\n')
else
    Database ={};
    Incremento_De_Lineas = Linea_Final - Linea_Inicial;

    while (Linea_Inicial - 1)
        fgetl(fileID);
        Linea_Inicial  = Linea_Inicial - 1;
    end

    for (i = 1 : Incremento_De_Lineas  + 1)
        LineaCompleta    = fgetl(fileID);
        Database(i)      = {LineaCompleta};
    end
    Database = Database';
end

